@@ -17,33 +17,29 @@ limitations under the License.
 package generator
 
 import (
+	"context"
 	"fmt"
 	"time"
 
 	"knative.dev/net-kourier/pkg/envoy"
-	network "knative.dev/networking/pkg"
-	"knative.dev/networking/pkg/ingress"
+	"knative.dev/net-kourier/pkg/knative"
 
+	v2 "github.com/envoyproxy/go-control-plane/envoy/api/v2"
 	endpoint "github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint"
+	route "github.com/envoyproxy/go-control-plane/envoy/api/v2/route"
 	"go.uber.org/zap"
 	kubev1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"knative.dev/net-kourier/pkg/knative"
-
 	kubeclient "k8s.io/client-go/kubernetes"
 	corev1listers "k8s.io/client-go/listers/core/v1"
 	"knative.dev/networking/pkg/apis/networking/v1alpha1"
 	"knative.dev/pkg/tracker"
-
-	v2 "github.com/envoyproxy/go-control-plane/envoy/api/v2"
-	route "github.com/envoyproxy/go-control-plane/envoy/api/v2/route"
 )
 
 type IngressTranslator struct {
 	kubeclient      kubeclient.Interface
 	endpointsLister corev1listers.EndpointsLister
-	localDomainName string
 	tracker         tracker.Interface
 	logger          *zap.SugaredLogger
 }
@@ -58,25 +54,24 @@ type translatedIngress struct {
 	internalVirtualHosts []*route.VirtualHost
 }
 
-func NewIngressTranslator(kubeclient kubeclient.Interface, endpointsLister corev1listers.EndpointsLister, localDomainName string, tracker tracker.Interface,
+func NewIngressTranslator(kubeclient kubeclient.Interface, endpointsLister corev1listers.EndpointsLister, tracker tracker.Interface,
 	logger *zap.SugaredLogger) IngressTranslator {
 	return IngressTranslator{
 		kubeclient:      kubeclient,
 		endpointsLister: endpointsLister,
-		localDomainName: localDomainName,
 		tracker:         tracker,
 		logger:          logger,
 	}
 }
 
-func (translator *IngressTranslator) translateIngress(ingress *v1alpha1.Ingress, extAuthzEnabled bool) (*translatedIngress, error) {
+func (translator *IngressTranslator) translateIngress(ctx context.Context, ingress *v1alpha1.Ingress, extAuthzEnabled bool) (*translatedIngress, error) {
 	res := &translatedIngress{
 		ingressName:      ingress.Name,
 		ingressNamespace: ingress.Namespace,
 	}
 
 	for _, ingressTLS := range ingress.Spec.TLS {
-		sniMatch, err := sniMatchFromIngressTLS(ingressTLS, translator.kubeclient)
+		sniMatch, err := sniMatchFromIngressTLS(ctx, ingressTLS, translator.kubeclient)
 
 		if err != nil {
 			translator.logger.Errorf("%s", err)
@@ -114,15 +109,15 @@ func (translator *IngressTranslator) translateIngress(ingress *v1alpha1.Ingress,
 				endpoints, err := translator.endpointsLister.Endpoints(split.ServiceNamespace).Get(split.ServiceName)
 				if apierrors.IsNotFound(err) {
 					translator.logger.Warnf("Endpoints '%s/%s' not yet created", split.ServiceNamespace, split.ServiceName)
-					break
+					return nil, nil
 				} else if err != nil {
 					return nil, fmt.Errorf("failed to fetch endpoints '%s/%s': %w", split.ServiceNamespace, split.ServiceName, err)
 				}
 
-				service, err := translator.kubeclient.CoreV1().Services(split.ServiceNamespace).Get(split.ServiceName, metav1.GetOptions{})
+				service, err := translator.kubeclient.CoreV1().Services(split.ServiceNamespace).Get(ctx, split.ServiceName, metav1.GetOptions{})
 				if apierrors.IsNotFound(err) {
 					translator.logger.Warnf("Service '%s/%s' not yet created", split.ServiceNamespace, split.ServiceName)
-					break
+					return nil, nil
 				} else if err != nil {
 					return nil, fmt.Errorf("failed to fetch service '%s/%s': %w", split.ServiceNamespace, split.ServiceName, err)
 				}
@@ -161,39 +156,28 @@ func (translator *IngressTranslator) translateIngress(ingress *v1alpha1.Ingress,
 			return nil, nil
 		}
 
-		externalDomains := knative.ExternalDomains(rule, translator.localDomainName)
-
-		// External should also be accessible internally
-		internalDomains := append(knative.InternalDomains(rule, translator.localDomainName), externalDomains...)
-
-		var virtualHost, internalVirtualHost route.VirtualHost
+		domains := knative.Domains(rule)
+		var virtualHost route.VirtualHost
 		if extAuthzEnabled {
 
-			visibility := ingress.Spec.Visibility
-			if visibility == "" { // Needed because visibility is optional
-				visibility = v1alpha1.IngressVisibilityClusterLocal
-			}
-
 			ContextExtensions := map[string]string{
 				"client":     "kourier",
-				"visibility": string(visibility),
+				"visibility": string(rule.Visibility),
 			}
 
 			ContextExtensions = mergeMapString(ContextExtensions, ingress.GetLabels())
-
-			virtualHost = envoy.NewVirtualHostWithExtAuthz(ingress.Name, ContextExtensions, externalDomains, ruleRoute)
-			internalVirtualHost = envoy.NewVirtualHostWithExtAuthz(ingress.Name, ContextExtensions, internalDomains,
-				ruleRoute)
+			virtualHost = envoy.NewVirtualHostWithExtAuthz(ingress.Name, ContextExtensions, domains, ruleRoute)
 		} else {
-			virtualHost = envoy.NewVirtualHost(ingress.GetName(), externalDomains, ruleRoute)
-			internalVirtualHost = envoy.NewVirtualHost(ingress.GetName(), internalDomains, ruleRoute)
+			virtualHost = envoy.NewVirtualHost(ingress.GetName(), domains, ruleRoute)
 		}
 
-		if knative.RuleIsExternal(rule, ingress.Spec.Visibility) {
+		if knative.RuleIsExternal(rule) {
 			res.externalVirtualHosts = append(res.externalVirtualHosts, &virtualHost)
+			// External should also be accessible internally
+			res.internalVirtualHosts = append(res.internalVirtualHosts, &virtualHost)
+		} else {
+			res.internalVirtualHosts = append(res.internalVirtualHosts, &virtualHost)
 		}
-
-		res.internalVirtualHosts = append(res.internalVirtualHosts, &internalVirtualHost)
 	}
 
 	return res, nil
@@ -244,18 +228,8 @@ func createRouteForRevision(ingressName string, ingressNamespace string, httpPat
 		routeTimeout = httpPath.Timeout.Duration
 	}
 
-	attempts := 0
-	var perTryTimeout time.Duration
-	if httpPath.Retries != nil {
-		attempts = httpPath.Retries.Attempts
-
-		if httpPath.Retries.PerTryTimeout != nil {
-			perTryTimeout = httpPath.Retries.PerTryTimeout.Duration
-		}
-	}
-
 	return envoy.NewRoute(
-		routeName, matchHeadersFromHTTPPath(httpPath), path, wrs, routeTimeout, uint32(attempts), perTryTimeout, httpPath.AppendHeaders,
+		routeName, matchHeadersFromHTTPPath(httpPath), path, wrs, routeTimeout, httpPath.AppendHeaders,
 	)
 }
 
@@ -276,9 +250,9 @@ func matchHeadersFromHTTPPath(httpPath v1alpha1.HTTPIngressPath) []*route.Header
 	return matchHeaders
 }
 
-func sniMatchFromIngressTLS(ingressTLS v1alpha1.IngressTLS, kubeClient kubeclient.Interface) (*envoy.SNIMatch, error) {
+func sniMatchFromIngressTLS(ctx context.Context, ingressTLS v1alpha1.IngressTLS, kubeClient kubeclient.Interface) (*envoy.SNIMatch, error) {
 	certChain, privateKey, err := sslCreds(
-		kubeClient, ingressTLS.SecretNamespace, ingressTLS.SecretName,
+		ctx, kubeClient, ingressTLS.SecretNamespace, ingressTLS.SecretName,
 	)
 
 	if err != nil {
@@ -299,26 +273,3 @@ func mergeMapString(a, b map[string]string) map[string]string {
 	}
 	return merged
 }
-
-// InsertKourierHeaders adds an AppendHeader rule so that any request going through a Gateway is tagged with
-// the version of the Ingress currently deployed on the Gateway and also a Random header to force envoy to reload
-// the new config part. This is a hack, this should be removed once we can move to the latest version of envoy.
-func InsertKourierHeaders(ing *v1alpha1.Ingress) error {
-	bytes, err := ingress.ComputeHash(ing)
-	if err != nil {
-		return fmt.Errorf("failed to compute the hash of the Ingress: %w", err)
-	}
-	hash := fmt.Sprintf("%x", bytes)
-	for _, rule := range ing.Spec.Rules {
-		if rule.HTTP == nil {
-			return fmt.Errorf("rule is missing HTTP block: %+v", rule)
-		}
-		for i := range rule.HTTP.Paths {
-			if rule.HTTP.Paths[i].AppendHeaders == nil {
-				rule.HTTP.Paths[i].AppendHeaders = make(map[string]string, 2)
-			}
-			rule.HTTP.Paths[i].AppendHeaders[network.HashHeaderName] = hash
-		}
-	}
-	return nil
-}
