@@ -17,7 +17,9 @@ limitations under the License.
 package generator
 
 import (
+	"context"
 	"fmt"
+	"sort"
 	"testing"
 
 	"knative.dev/net-kourier/pkg/envoy"
@@ -35,6 +37,7 @@ import (
 	route "github.com/envoyproxy/go-control-plane/envoy/api/v2/route"
 	"gotest.tools/assert"
 	kubev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -110,9 +113,11 @@ func TestTrafficSplits(t *testing.T) {
 	}
 
 	kubeClient := fake.NewSimpleClientset()
+	ctx := context.Background()
 	// Create the Kubernetes services associated to the Knative services that
 	// appear in the ingress above
 	if err := createServicesWithNames(
+		ctx,
 		kubeClient,
 		[]string{"hello-world-rev1", "hello-world-rev2"},
 		"default",
@@ -121,9 +126,9 @@ func TestTrafficSplits(t *testing.T) {
 	}
 
 	ingressTranslator := NewIngressTranslator(
-		kubeClient, newMockedEndpointsLister(), "cluster.local", &pkgtest.FakeTracker{}, logtest.TestLogger(t))
+		kubeClient, newMockedEndpointsLister(), &pkgtest.FakeTracker{}, logtest.TestLogger(t))
 
-	ingressTranslation, err := ingressTranslator.translateIngress(&ingress, false)
+	ingressTranslation, err := ingressTranslator.translateIngress(ctx, &ingress, false)
 	if err != nil {
 		t.Error(err)
 	}
@@ -166,6 +171,67 @@ func TestTrafficSplits(t *testing.T) {
 	)
 }
 
+func TestIngressVisibility(t *testing.T) {
+	ctx := context.Background()
+	kubeClient := fake.NewSimpleClientset()
+	tests := []struct {
+		name       string
+		hosts      []string
+		extDomains []string
+		intDomains []string
+		visibility v1alpha1.IngressVisibility
+	}{{
+		name:       "external visibility",
+		hosts:      []string{"hello.default.example.com"},
+		extDomains: []string{"hello.default.example.com", "hello.default.example.com:*"},
+		// External should also be accessible internally
+		intDomains: []string{"hello.default.example.com", "hello.default.example.com:*"},
+		visibility: v1alpha1.IngressVisibilityExternalIP,
+	}, {
+		name:       "cluster local visibility",
+		hosts:      []string{"hello.default", "hello.default.svc", "hello.default.svc.cluster.local"},
+		intDomains: []string{"hello.default", "hello.default:*", "hello.default.svc", "hello.default.svc:*", "hello.default.svc.cluster.local", "hello.default.svc.cluster.local:*"},
+		visibility: v1alpha1.IngressVisibilityClusterLocal,
+	}}
+
+	for num, test := range tests {
+		t.Run(test.name, func(t *testing.T) {
+			ingress := createIngress(fmt.Sprintf("hello-%d", num), test.hosts, test.visibility)
+
+			// Create the Kubernetes services associated to the Knative service that
+			// appears in the ingress above
+			if err := createServicesWithNames(ctx, kubeClient, []string{ingress.ObjectMeta.Name}, ingress.ObjectMeta.Namespace); err != nil {
+				t.Error(err)
+			}
+
+			ingressTranslator := NewIngressTranslator(
+				kubeClient, newMockedEndpointsLister(), &pkgtest.FakeTracker{}, logtest.TestLogger(t))
+
+			translatedIngress, err := ingressTranslator.translateIngress(ctx, ingress, false)
+			if err != nil {
+				t.Error(err)
+			}
+			var extDomains, intDomains []string
+			var extHosts, intHosts []*route.VirtualHost
+			extHosts = translatedIngress.externalVirtualHosts
+			intHosts = translatedIngress.internalVirtualHosts
+
+			for _, v := range extHosts {
+				extDomains = append(extDomains, v.Domains...)
+			}
+			for _, v := range intHosts {
+				intDomains = append(intDomains, v.Domains...)
+			}
+			sort.Strings(extDomains)
+			sort.Strings(intDomains)
+			sort.Strings(test.extDomains)
+			sort.Strings(test.intDomains)
+			assert.DeepEqual(t, extDomains, test.extDomains)
+			assert.DeepEqual(t, intDomains, test.intDomains)
+		})
+	}
+}
+
 func TestIngressWithTLS(t *testing.T) {
 	// TLS data for the test
 	tlsSecretName := "tls-secret"
@@ -174,6 +240,7 @@ func TestIngressWithTLS(t *testing.T) {
 	tlsCert := "some-cert"
 	tlsKey := "tls-key"
 	svcNamespace := "default"
+	ctx := context.Background()
 
 	ingress := createIngressWithTLS(tlsHosts, tlsSecretName, tlsSecretNamespace, svcNamespace)
 
@@ -181,20 +248,20 @@ func TestIngressWithTLS(t *testing.T) {
 
 	// Create the Kubernetes services associated to the Knative service that
 	// appears in the ingress above
-	if err := createServicesWithNames(kubeClient, []string{ingress.ObjectMeta.Name}, svcNamespace); err != nil {
+	if err := createServicesWithNames(ctx, kubeClient, []string{ingress.ObjectMeta.Name}, svcNamespace); err != nil {
 		t.Error(err)
 	}
 
 	// Create secret with TLS data
-	err := createSecret(kubeClient, tlsSecretNamespace, tlsSecretName, tlsCert, tlsKey)
+	err := createSecret(ctx, kubeClient, tlsSecretNamespace, tlsSecretName, tlsCert, tlsKey)
 	if err != nil {
 		t.Error(err)
 	}
 
 	ingressTranslator := NewIngressTranslator(
-		kubeClient, newMockedEndpointsLister(), "cluster.local", &pkgtest.FakeTracker{}, logtest.TestLogger(t))
+		kubeClient, newMockedEndpointsLister(), &pkgtest.FakeTracker{}, logtest.TestLogger(t))
 
-	translatedIngress, err := ingressTranslator.translateIngress(ingress, false)
+	translatedIngress, err := ingressTranslator.translateIngress(ctx, ingress, false)
 	if err != nil {
 		t.Error(err)
 	}
@@ -217,17 +284,18 @@ func TestReturnsErrorWhenTLSSecretDoesNotExist(t *testing.T) {
 	ingress := createIngressWithTLS(tlsHosts, tlsSecretName, tlsSecretNamespace, svcNamespace)
 
 	kubeClient := fake.NewSimpleClientset()
+	ctx := context.Background()
 
 	// Create the Kubernetes services associated to the Knative service that
 	// appears in the ingress above
-	if err := createServicesWithNames(kubeClient, []string{ingress.ObjectMeta.Name}, "default"); err != nil {
+	if err := createServicesWithNames(ctx, kubeClient, []string{ingress.ObjectMeta.Name}, "default"); err != nil {
 		t.Error(err)
 	}
 
 	ingressTranslator := NewIngressTranslator(
-		kubeClient, newMockedEndpointsLister(), "cluster.local", &pkgtest.FakeTracker{}, logtest.TestLogger(t))
+		kubeClient, newMockedEndpointsLister(), &pkgtest.FakeTracker{}, logtest.TestLogger(t))
 
-	_, err := ingressTranslator.translateIngress(ingress, false)
+	_, err := ingressTranslator.translateIngress(ctx, ingress, false)
 
 	assert.Error(t, err, fmt.Sprintf("secrets \"%s\" not found", tlsSecretName))
 }
@@ -256,6 +324,35 @@ func (endpoints *endpoints) Get(name string) (*kubev1.Endpoints, error) {
 	return &kubev1.Endpoints{}, nil
 }
 
+func createIngress(name string, hosts []string, visibility v1alpha1.IngressVisibility) *v1alpha1.Ingress {
+	return &v1alpha1.Ingress{
+		TypeMeta: v1.TypeMeta{
+			Kind:       "Ingress",
+			APIVersion: "networking.internal.knative.dev/v1alpha1",
+		},
+		ObjectMeta: v1.ObjectMeta{
+			Name: name,
+		},
+		Spec: v1alpha1.IngressSpec{
+			Rules: []v1alpha1.IngressRule{{
+				Hosts:      hosts,
+				Visibility: visibility,
+				HTTP: &v1alpha1.HTTPIngressRuleValue{
+					Paths: []v1alpha1.HTTPIngressPath{{
+						Splits: []v1alpha1.IngressBackendSplit{{
+							IngressBackend: v1alpha1.IngressBackend{
+								ServiceName: name,
+								ServicePort: intstr.FromInt(80),
+							},
+						}},
+					}},
+				},
+			}},
+		},
+		Status: v1alpha1.IngressStatus{},
+	}
+}
+
 func createIngressWithTLS(hosts []string, secretName string, secretNamespace string, svcNamespace string) *v1alpha1.Ingress {
 	return &v1alpha1.Ingress{
 		TypeMeta: v1.TypeMeta{
@@ -273,6 +370,7 @@ func createIngressWithTLS(hosts []string, secretName string, secretNamespace str
 			}},
 			Rules: []v1alpha1.IngressRule{
 				{
+					Visibility: v1alpha1.IngressVisibilityExternalIP,
 					HTTP: &v1alpha1.HTTPIngressRuleValue{
 						Paths: []v1alpha1.HTTPIngressPath{
 							{
@@ -297,14 +395,13 @@ func createIngressWithTLS(hosts []string, secretName string, secretNamespace str
 					},
 				},
 			},
-			Visibility: "",
 		},
 		Status: v1alpha1.IngressStatus{},
 	}
 
 }
 
-func createSecret(kubeClient kubernetes.Interface, secretNamespace string, secretName string, cert string, key string) error {
+func createSecret(ctx context.Context, kubeClient kubernetes.Interface, secretNamespace string, secretName string, cert string, key string) error {
 	tlsSecret := kubev1.Secret{
 		ObjectMeta: v1.ObjectMeta{
 			Name: secretName,
@@ -315,11 +412,11 @@ func createSecret(kubeClient kubernetes.Interface, secretNamespace string, secre
 		},
 	}
 
-	_, err := kubeClient.CoreV1().Secrets(secretNamespace).Create(&tlsSecret)
+	_, err := kubeClient.CoreV1().Secrets(secretNamespace).Create(ctx, &tlsSecret, metav1.CreateOptions{})
 	return err
 }
 
-func createServicesWithNames(kubeclient kubernetes.Interface, names []string, namespace string) error {
+func createServicesWithNames(ctx context.Context, kubeclient kubernetes.Interface, names []string, namespace string) error {
 	for _, serviceName := range names {
 		service := kubev1.Service{
 			ObjectMeta: v1.ObjectMeta{
@@ -327,7 +424,7 @@ func createServicesWithNames(kubeclient kubernetes.Interface, names []string, na
 			},
 		}
 
-		_, err := kubeclient.CoreV1().Services(namespace).Create(&service)
+		_, err := kubeclient.CoreV1().Services(namespace).Create(ctx, &service, metav1.CreateOptions{})
 
 		if err != nil {
 			return err
