@@ -27,24 +27,13 @@ import (
 var testRule = v1alpha1.IngressRule{
 	Hosts: []string{
 		"helloworld-go.default.svc.cluster.local",
-		"helloworld-go.default.example.com",
+		"helloworld-go.default.svc",
+		"helloworld-go.default",
 	},
 }
 
-func TestExternalDomains(t *testing.T) {
-	externalDomains := ExternalDomains(testRule, "cluster.local")
-
-	expected := []string{
-		"helloworld-go.default.example.com",
-		"helloworld-go.default.example.com:*",
-	}
-	sort.Strings(externalDomains)
-	sort.Strings(expected)
-	assert.DeepEqual(t, externalDomains, expected)
-}
-
-func TestInternalDomains(t *testing.T) {
-	internalDomains := InternalDomains(testRule, "cluster.local")
+func TestDomains(t *testing.T) {
+	domains := Domains(testRule)
 
 	expected := []string{
 		"helloworld-go.default",
@@ -54,9 +43,9 @@ func TestInternalDomains(t *testing.T) {
 		"helloworld-go.default.svc.cluster.local",
 		"helloworld-go.default.svc.cluster.local:*",
 	}
-	sort.Strings(internalDomains)
+	sort.Strings(domains)
 	sort.Strings(expected)
-	assert.DeepEqual(t, internalDomains, expected)
+	assert.DeepEqual(t, domains, expected)
 }
 
 func TestRuleIsExternalWithVisibility(t *testing.T) {
@@ -67,24 +56,6 @@ func TestRuleIsExternalWithVisibility(t *testing.T) {
 		Visibility: v1alpha1.IngressVisibilityClusterLocal,
 	}
 
-	assert.Equal(t, RuleIsExternal(externalRule, ""), true)
-	assert.Equal(t, RuleIsExternal(internalRule, ""), false)
-}
-
-func TestRuleIsExternalWithIngressVisibility(t *testing.T) {
-	ruleWithoutVisibility := v1alpha1.IngressRule{Visibility: ""}
-
-	assert.Equal(
-		t, RuleIsExternal(ruleWithoutVisibility, v1alpha1.IngressVisibilityClusterLocal), false,
-	)
-	assert.Equal(
-		t, RuleIsExternal(ruleWithoutVisibility, v1alpha1.IngressVisibilityExternalIP), true,
-	)
-}
-
-func TestRuleIsExternalWithoutVisibility(t *testing.T) {
-	ruleWithoutVisibility := v1alpha1.IngressRule{Visibility: ""}
-
-	// Knative defaults to external, so it should return true
-	assert.Equal(t, RuleIsExternal(ruleWithoutVisibility, ""), true)
+	assert.Equal(t, RuleIsExternal(externalRule), true)
+	assert.Equal(t, RuleIsExternal(internalRule), false)
 }
