@@ -18,6 +18,7 @@ package ingress
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
 	"knative.dev/net-kourier/pkg/config"
@@ -49,28 +50,42 @@ var _ ingress.ReadOnlyInterface = (*Reconciler)(nil)
 var _ ingress.Finalizer = (*Reconciler)(nil)
 var _ ingress.ReadOnlyFinalizer = (*Reconciler)(nil)
 
-func (r *Reconciler) ReconcileKind(ctx context.Context, ingress *v1alpha1.Ingress) reconciler.Event {
-	before := ingress.DeepCopy()
+func (r *Reconciler) ReconcileKind(ctx context.Context, ing *v1alpha1.Ingress) reconciler.Event {
+	ing.SetDefaults(ctx)
+	before := ing.DeepCopy()
 
-	r.ObserveKind(ctx, ingress)
+	if err := r.updateIngress(ctx, ing); errors.Is(err, generator.ErrDomainConflict) {
+		// If we had an error due to a duplicated domain, we must mark the ingress as failed with a
+		// custom status. We don't want to return an error in this case as we want to update its status.
+		logging.FromContext(ctx).Info(err.Error())
+		ing.Status.MarkLoadBalancerFailed("DomainConflict", "Ingress rejected: "+err.Error())
+		return nil
+	} else if err != nil {
+		return fmt.Errorf("failed to update ingress: %w", err)
+	}
 
-	if ready, err := r.statusManager.IsReady(context.TODO(), before); err != nil {
-		return err
-	} else if ready {
-		knative.MarkIngressReady(ingress)
+	if !ing.IsReady() {
+		ready, err := r.statusManager.IsReady(context.TODO(), before)
+		if err != nil {
+			return fmt.Errorf("failed to probe Ingress %s/%s: %w", ing.GetNamespace(), ing.GetName(), err)
+		}
+		if ready {
+			knative.MarkIngressReady(ing)
+		} else {
+			ing.Status.MarkLoadBalancerNotReady()
+		}
 	}
 
 	return nil
 }
 
-func (r *Reconciler) ObserveKind(ctx context.Context, ingress *v1alpha1.Ingress) reconciler.Event {
-	ingress.SetDefaults(ctx)
+func (r *Reconciler) ObserveKind(ctx context.Context, ing *v1alpha1.Ingress) reconciler.Event {
+	ing.SetDefaults(ctx)
 
-	if err := r.updateIngress(ctx, ingress); err == generator.ErrDomainConflict {
-		// If we had an error due to a duplicated domain, we must mark the ingress as failed with a
-		// custom status. We don't want to return an error in this case as we want to update its status.
-		logging.FromContext(ctx).Errorw(err.Error(), ingress.Name, ingress.Namespace)
-		ingress.Status.MarkLoadBalancerFailed("DomainConflict", "Ingress rejected as its domain conflicts with another ingress")
+	if err := r.updateIngress(ctx, ing); errors.Is(err, generator.ErrDomainConflict) {
+		// If we had an error due to a duplicated domain, just abort.
+		logging.FromContext(ctx).Info(err.Error())
+		return nil
 	} else if err != nil {
 		return fmt.Errorf("failed to update ingress: %w", err)
 	}
@@ -92,7 +107,7 @@ func (r *Reconciler) ObserveFinalizeKind(ctx context.Context, ing *v1alpha1.Ingr
 		r.statusManager.CancelIngressProbing(ingress)
 	}
 
-	if err := r.caches.DeleteIngressInfo(ing.Name, ing.Namespace, r.kubeClient); err != nil {
+	if err := r.caches.DeleteIngressInfo(ctx, ing.Name, ing.Namespace, r.kubeClient); err != nil {
 		return err
 	}
 
@@ -104,7 +119,7 @@ func (r *Reconciler) updateIngress(ctx context.Context, ingress *v1alpha1.Ingres
 	logger.Infof("Updating Ingress %s namespace: %s", ingress.Name, ingress.Namespace)
 
 	if err := generator.UpdateInfoForIngress(
-		r.caches, ingress, r.kubeClient, r.ingressTranslator, logger, r.extAuthz,
+		ctx, r.caches, ingress, r.kubeClient, r.ingressTranslator, r.extAuthz,
 	); err != nil {
 		return err
 	}
