@@ -17,9 +17,9 @@ limitations under the License.
 package ha
 
 import (
-	"testing"
-
+	"context"
 	"net/url"
+	"testing"
 
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"knative.dev/networking/pkg/apis/networking/v1alpha1"
@@ -35,8 +35,7 @@ const (
 func createIngressSpec(name string, port int) v1alpha1.IngressSpec {
 	return v1alpha1.IngressSpec{
 		Rules: []v1alpha1.IngressRule{{
-			Hosts:      []string{name + domain},
-			Visibility: v1alpha1.IngressVisibilityExternalIP,
+			Hosts: []string{name + domain},
 			HTTP: &v1alpha1.HTTPIngressRuleValue{
 				Paths: []v1alpha1.HTTPIngressPath{{
 					Splits: []v1alpha1.IngressBackendSplit{{
@@ -48,13 +47,15 @@ func createIngressSpec(name string, port int) v1alpha1.IngressSpec {
 					}},
 				}},
 			},
+			Visibility: v1alpha1.IngressVisibilityExternalIP,
 		}},
 	}
 }
 
-func assertIngressEventuallyWorks(t *testing.T, clients *test.Clients, url *url.URL) {
+func assertIngressEventuallyWorks(ctx context.Context, t *testing.T, clients *test.Clients, url *url.URL) {
 	t.Helper()
 	if _, err := pkgTest.WaitForEndpointState(
+		ctx,
 		clients.KubeClient,
 		t.Logf,
 		url,
